@@ -7,7 +7,7 @@ import hildon
 from os import listdir, path, system
 from ConfigParser import SafeConfigParser
 
-version = "1.6-4"
+version = "1.6-5"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
@@ -568,7 +568,7 @@ class Main(object):
         buttonReverse.set_label('Reverse sections order')
         buttonReverse.connect("clicked", self.reverse_clicked)
         buttonAbout = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
-        buttonAbout.set_label('About')
+        buttonAbout.set_label('Info')
         buttonAbout.connect("clicked", self.about_clicked)
     
         menu.append(buttonRestart)
@@ -595,12 +595,12 @@ class Main(object):
         self.write_config()
     
     def about_clicked(self, dummy):
-        self.about = gtk.Dialog("About", None)
+        self.about = gtk.Dialog("Info", None)
         logo = gtk.image_new_from_file("/usr/share/icons/hicolor/64x64/apps/openssh-status.png")
         textApp = gtk.Label("<big><b>OpenSSH Status Widget  "+version+"</b></big>")
         textApp.set_use_markup(True)
         textApp.set_line_wrap(True)
-        textIandI = gtk.Label("Created by Marc Pöpperl (rasmarc)\n")
+        textIandI = gtk.Label("Created by Marc Poepperl (rasmarc)\n")
         buttonForum = hildon.Button(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL | hildon.BUTTON_STYLE_NORMAL)
         buttonForum.set_label('Go to forum thread')
         vbox2 = gtk.VBox(False,16)
